@@ -51,6 +51,7 @@ import org.apache.flink.kubernetes.operator.service.AbstractFlinkService;
 import org.apache.flink.kubernetes.operator.service.CheckpointHistoryWrapper;
 import org.apache.flink.kubernetes.operator.service.SuspendMode;
 import org.apache.flink.kubernetes.operator.standalone.StandaloneKubernetesConfigOptionsInternal;
+import org.apache.flink.runtime.client.DuplicateJobSubmissionException;
 import org.apache.flink.runtime.client.JobStatusMessage;
 import org.apache.flink.runtime.clusterframework.ApplicationStatus;
 import org.apache.flink.runtime.execution.ExecutionState;
@@ -139,6 +140,8 @@ public class TestingFlinkService extends AbstractFlinkService {
     @Setter private boolean deployFailure = false;
     @Setter private Exception makeItFailWith;
     @Setter private boolean triggerSavepointFailure = false;
+    @Setter private Exception savepointTriggerException = null;
+    @Setter private String savepointFetchError = null;
     @Setter private boolean disposeSavepointFailure = false;
     @Setter private Runnable sessionJobSubmittedCallback;
     @Setter private PodList podList = new PodList();
@@ -290,6 +293,10 @@ public class TestingFlinkService extends AbstractFlinkService {
         if (deployFailure) {
             throw new Exception("Deployment failure");
         }
+        if (jobs.stream().anyMatch(job -> job.f1.getJobId().equals(jobID))) {
+            throw DuplicateJobSubmissionException.of(jobID);
+        }
+
         JobStatusMessage jobStatusMessage =
                 new JobStatusMessage(
                         jobID,
@@ -375,6 +382,9 @@ public class TestingFlinkService extends AbstractFlinkService {
             String savepointDirectory,
             Configuration conf)
             throws Exception {
+        if (savepointTriggerException != null) {
+            throw savepointTriggerException;
+        }
         if (triggerSavepointFailure) {
             throw new Exception(SNAPSHOT_ERROR_MESSAGE);
         }
@@ -398,6 +408,10 @@ public class TestingFlinkService extends AbstractFlinkService {
     public SavepointFetchResult fetchSavepointInfo(
             String triggerId, String jobId, Configuration conf) {
 
+        if (savepointFetchError != null) {
+            return SavepointFetchResult.error(savepointFetchError);
+        }
+
         if (savepointTriggers.containsKey(triggerId)) {
             if (savepointTriggers.get(triggerId)) {
                 return SavepointFetchResult.completed("savepoint_" + savepointCounter++);
@@ -626,10 +640,13 @@ public class TestingFlinkService extends AbstractFlinkService {
                 .findAny()
                 .ifPresent(
                         t -> {
-                            if (!t.f1.getJobState().isGloballyTerminalState()) {
-                                throw new RuntimeException(
-                                        "Checkpoint should not be queried if job is not in terminal state");
-                            }
+                            // TODO: check this... for example getting the SP/CP
+                            //   in RUNNING state should be valid
+                            // if (!t.f1.getJobState().isGloballyTerminalState()) {
+                            //      throw new RuntimeException(
+                            //          "Checkpoint should not be
+                            //          queried if job is not in terminal state");
+                            // }
                         });
 
         return super.getLastCheckpoint(jobId, conf);
@@ -771,4 +788,20 @@ public class TestingFlinkService extends AbstractFlinkService {
                 new JobExceptionsInfoWithHistory(exceptionHistory);
         jobExceptionsMap.put(jobId, newExceptionHistory);
     }
+
+    public void setSavepointTriggerException(Exception exception) {
+        this.savepointTriggerException = exception;
+    }
+
+    public void clearSavepointTriggerException() {
+        this.savepointTriggerException = null;
+    }
+
+    public void setSavepointFetchError(String error) {
+        this.savepointFetchError = error;
+    }
+
+    public void clearSavepointFetchError() {
+        this.savepointFetchError = null;
+    }
 }
