@@ -72,6 +72,7 @@ import static org.apache.flink.api.common.JobStatus.RESTARTING;
 import static org.apache.flink.api.common.JobStatus.RUNNING;
 import static org.apache.flink.kubernetes.operator.config.KubernetesOperatorConfigOptions.SNAPSHOT_RESOURCE_ENABLED;
 import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
@@ -501,6 +502,7 @@ public class ApplicationReconcilerUpgradeModeTest extends OperatorTestBase {
     @ValueSource(booleans = {true, false})
     public void testLastStateMaxCheckpointAge(boolean cancellable) throws Exception {
         var deployment = TestUtils.buildApplicationCluster();
+        deployment.getStatus().setJobManagerDeploymentStatus(JobManagerDeploymentStatus.READY);
         deployment
                 .getSpec()
                 .getFlinkConfiguration()
@@ -643,6 +645,7 @@ public class ApplicationReconcilerUpgradeModeTest extends OperatorTestBase {
         jobStatus.setJobId(new JobID().toString());
 
         // Running state, savepoint if possible
+        deployment.getStatus().setJobManagerDeploymentStatus(JobManagerDeploymentStatus.READY);
         jobStatus.setState(RUNNING);
         var ctx = getResourceContext(deployment);
         var deployConf = ctx.getDeployConfig(deployment.getSpec());
@@ -654,6 +657,7 @@ public class ApplicationReconcilerUpgradeModeTest extends OperatorTestBase {
                 jobReconciler.getJobUpgrade(ctx, deployConf));
 
         // Not running (but cancellable)
+        deployment.getStatus().setJobManagerDeploymentStatus(JobManagerDeploymentStatus.READY);
         jobStatus.setState(RESTARTING);
         assertEquals(
                 AbstractJobReconciler.JobUpgrade.lastStateUsingCancel(),
@@ -667,17 +671,26 @@ public class ApplicationReconcilerUpgradeModeTest extends OperatorTestBase {
     }
 
     private static Stream<Arguments> testLastStateCancelParams() {
-        return Stream.of(
-                Arguments.of(UpgradeMode.LAST_STATE, true),
-                Arguments.of(UpgradeMode.LAST_STATE, false),
-                Arguments.of(UpgradeMode.SAVEPOINT, true),
-                Arguments.of(UpgradeMode.SAVEPOINT, false));
+        var out = new ArrayList<Arguments>();
+        for (var upgradeMode : List.of(UpgradeMode.SAVEPOINT, UpgradeMode.LAST_STATE)) {
+            for (boolean allowFallback : List.of(true, false)) {
+                for (var jmStatus : JobManagerDeploymentStatus.values()) {
+                    out.add(Arguments.of(upgradeMode, allowFallback, jmStatus));
+                }
+            }
+        }
+        return out.stream();
     }
 
     @ParameterizedTest
     @MethodSource("testLastStateCancelParams")
-    public void testLastStateNoHaMeta(UpgradeMode upgradeMode, boolean allowFallback)
+    public void testLastStateNoHaMeta(
+            UpgradeMode upgradeMode, boolean allowFallback, JobManagerDeploymentStatus jmStatus)
             throws Exception {
+        if (upgradeMode == UpgradeMode.LAST_STATE && !allowFallback) {
+            // This cannot happen
+            return;
+        }
         var jobReconciler = (ApplicationReconciler) this.reconciler.getReconciler();
         var deployment = TestUtils.buildApplicationCluster();
         deployment
@@ -702,6 +715,8 @@ public class ApplicationReconcilerUpgradeModeTest extends OperatorTestBase {
 
         // Set job status to running
         var jobStatus = deployment.getStatus().getJobStatus();
+        deployment.getStatus().setJobManagerDeploymentStatus(jmStatus);
+
         long now = System.currentTimeMillis();
 
         jobStatus.setStartTime(Long.toString(now));
@@ -712,15 +727,21 @@ public class ApplicationReconcilerUpgradeModeTest extends OperatorTestBase {
         var ctx = getResourceContext(deployment);
         var deployConf = ctx.getDeployConfig(deployment.getSpec());
 
-        if (upgradeMode == UpgradeMode.LAST_STATE) {
-            assertEquals(
-                    AbstractJobReconciler.JobUpgrade.lastStateUsingCancel(),
-                    jobReconciler.getJobUpgrade(ctx, deployConf));
+        if (List.of(JobManagerDeploymentStatus.ERROR, JobManagerDeploymentStatus.MISSING)
+                .contains(jmStatus)) {
+            assertThatThrownBy(() -> jobReconciler.getJobUpgrade(ctx, deployConf))
+                    .isInstanceOf(UpgradeFailureException.class)
+                    .hasMessageContaining(
+                            "JobManager deployment is missing and HA metadata is not available");
         } else {
+            boolean immediatelyCancellable =
+                    (upgradeMode == UpgradeMode.LAST_STATE || allowFallback)
+                            && jmStatus == JobManagerDeploymentStatus.READY;
             assertEquals(
-                    allowFallback
+                    immediatelyCancellable
                             ? AbstractJobReconciler.JobUpgrade.lastStateUsingCancel()
-                            : AbstractJobReconciler.JobUpgrade.pendingUpgrade(),
+                            : new AbstractJobReconciler.JobUpgrade(
+                                    null, null, false, allowFallback, true),
                     jobReconciler.getJobUpgrade(ctx, deployConf));
         }
     }
